Package: kstMatrix
Type: Package
Date: 2026-04-26
Version: 2.3-2
Title: Basic Functions in Knowledge Space Theory Using Matrix
        Representation
Description: Knowledge space theory by Doignon and Falmagne (1999)
   <doi:10.1007/978-3-642-58625-5> is a set- and order-theoretical
   framework, which proposes mathematical formalisms to operationalize
   knowledge structures in a particular domain. The 'kstMatrix' package 
   provides basic functionalities to generate, handle, and manipulate 
   knowledge structures and knowledge spaces. Opposed to the 'kst'
   package, 'kstMatrix' uses matrix representations for knowledge
   structures. Furthermore, 'kstMatrix' contains several knowledge spaces
   developed by the research group around Cornelia Dowling through
   querying experts.
Depends: R (>= 4.4.0)
Imports: stats, grDevices, sets, pks, tidyr, DiagrammeR, rsvg
Suggests: DiagrammeRsvg, litedown, markdown
Authors@R: c(person(given = "Cord", family = "Hockemeyer",
                    role = c("aut", "cre"),
                    email = "cord.hockemeyer@uni-graz.at"),
             person(given = "Peter", family = "Steiner",
                    role = c("aut"),
                    email = "Peter.Steiner@PHSG.ch"),
             person(given = "Wai", family = "Wong",
                    role = c("aut"),
                    email = "wai.wong@kuleuven.be")
             )
Maintainer: Cord Hockemeyer <cord.hockemeyer@uni-graz.at>
License: GPL-3
NeedsCompilation: yes
Repository: CRAN
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
VignetteBuilder: litedown
Packaged: 2026-04-26 11:34:06 UTC; cord
Author: Cord Hockemeyer [aut, cre],
  Peter Steiner [aut],
  Wai Wong [aut]
Date/Publication: 2026-04-26 12:20:02 UTC
Built: R 4.5.2; aarch64-apple-darwin20; 2026-04-27 00:01:23 UTC; unix
Archs: kstMatrix.so.dSYM
