# Generated by roxygen2: do not edit by hand

S3method(kmbasis,kmsurmisefunction)
S3method(kmbasis,kmsurmiserelation)
S3method(kmbasis,matrix)
S3method(kmunionclosure,kmdata)
S3method(kmunionclosure,kmfamset)
S3method(kmunionclosure,kmstructure)
S3method(plot,kmfamset)
S3method(plot,kmneighbourhood)
S3method(plot,kmsurmiserelation)
export(kmSF2basis)
export(kmSR2basis)
export(kmSRvalidate)
export(kmassess)
export(kmassessbayesian)
export(kmassesshalfsplit)
export(kmassessinformative)
export(kmassessmentsimulation)
export(kmassessmultiplicative)
export(kmbasis)
export(kmbasisfringe)
export(kmbasisinnerfringe)
export(kmbasisneighbourhood)
export(kmbasisouterfringe)
export(kmcolors)
export(kmdist)
export(kmdoubleequal)
export(kmeqreduction)
export(kmfamset)
export(kmfringe)
export(kmgenerate)
export(kmgradations)
export(kmiita2SR)
export(kminnerfringe)
export(kmiswellgraded)
export(kmlearningpaths)
export(kmmaximalspace)
export(kmminimalspace)
export(kmneighbourhood)
export(kmnneighbourhood)
export(kmnotions)
export(kmouterfringe)
export(kmsassess)
export(kmsetdistance)
export(kmsetiselement)
export(kmsimulate)
export(kmspace)
export(kmstructure)
export(kmsurmisefunction)
export(kmsurmiserelation)
export(kmsymmsetdiff)
export(kmunionclosure)
export(kmvalidate)
importFrom(DiagrammeR,grViz)
importFrom(grDevices,cm.colors)
importFrom(grDevices,dev.off)
importFrom(grDevices,jpeg)
importFrom(grDevices,terrain.colors)
importFrom(pks,as.binmat)
importFrom(pks,as.pattern)
importFrom(rsvg,rsvg_png)
importFrom(sets,"%e%")
importFrom(sets,as.set)
importFrom(sets,set)
importFrom(sets,set_is_subset)
importFrom(stats,runif)
importFrom(tidyr,unnest)
useDynLib(kstMatrix)
