#' Knowledge space on linear functions
#'
#' Basis of a small knowledge space and list of items on linear functions
#' used in a manuscript by Steiner et al.
#'
#' @docType data
#'
#' @usage phsg
#'
#' @format A list containing the basis and the list of items
#'
"phsg"
