% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmsubstructure.R
\name{kmsubstructure}
\alias{kmsubstructure}
\alias{kmsubstructure.kmdata}
\alias{kmsubstructure.kmbasis}
\alias{kmsubstructure.kmstructure}
\alias{kmsubstructure.kmspace}
\alias{kmsubstructure.kmsurmiserelation}
\alias{kmsubstructure.kmsurmisefunction}
\title{Reduce a KST object to a subset of items}
\usage{
kmsubstructure(x, items)

\method{kmsubstructure}{kmdata}(x, items)

\method{kmsubstructure}{kmbasis}(x, items)

\method{kmsubstructure}{kmstructure}(x, items)

\method{kmsubstructure}{kmspace}(x, items)

\method{kmsubstructure}{kmsurmiserelation}(x, items)

\method{kmsubstructure}{kmsurmisefunction}(x, items)
}
\arguments{
\item{x}{KST object}

\item{items}{Selection of items (vector) to which the KST object shall be reduced}
}
\value{
Sub structure KST object (the kstMatrix class and its properties
are preserved)

\code{kmsubstructure()} takes a KST object and determines a sub-structure
based on the list of items.

The items can be specified through their item names or through the respective
column numbers. At least two items must be specified.
}
\description{
Reduce a KST object to a subset of items
}
\examples{
phsg$basis
kmsubstructure(phsg$basis, c("I1", "I2", "I5"))

}
\seealso{
Other Functions for working with knowledge structures:
\code{\link[=kmeqreduction]{kmeqreduction()}},
\code{\link[=kmexpand]{kmexpand()}},
\code{\link[=kmintersection]{kmintersection()}},
\code{\link[=kmmesh]{kmmesh()}},
\code{\link[=kmnotions]{kmnotions()}},
\code{\link{kmtrivial}},
\code{\link[=kmunion]{kmunion()}}
}
\concept{Functions for working with knowledge structures}
