% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Deprecated.R
\name{kmSR2basis}
\alias{kmSR2basis}
\title{DEPRECATED: \code{kmSR2basis()} has been replaced by \code{kmbasis()}.}
\usage{
kmSR2basis(x)
}
\arguments{
\item{x}{Surmise relation}
}
\value{
Corresponding basis
}
\description{
DEPRECATED: \code{kmSR2basis()} has been replaced by \code{kmbasis()}.
}
\seealso{
Other Deprecated functions and methods:
\code{\link[=kmSF2basis]{kmSF2basis()}},
\code{\link[=kmSRdiagram]{kmSRdiagram()}},
\code{\link[=kmbasisdiagram]{kmbasisdiagram()}},
\code{\link[=kmhasse]{kmhasse()}}
}
\concept{Deprecated functions and methods}
