% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmiswellgraded.R
\name{kmiswellgraded}
\alias{kmiswellgraded}
\title{Check for wellgradedness of a knowledge structure}
\usage{
kmiswellgraded(x)
}
\arguments{
\item{x}{\code{kmspace} or \code{kmbasis}}
}
\value{
Logical value specifying whether \code{x} is well-graded
}
\description{
\code{kmiswellgraded()} returns whether a knowledge space (or its basis)
is well-graded.
}
\examples{
kmiswellgraded(xpl$space)

}
\references{
Doignon, J.-P. & Falmagne, J.-C. (1999). \emph{Knowledge Spaces.}
Springer–Verlag, Berlin.
}
\seealso{
Other Properties of knowledge structures:
\code{\link[=kmheights]{kmheights()}},
\code{\link[=kmnotions]{kmnotions()}}

Other Functions for wellgradedness & learning paths:
\code{\link[=kmgradations]{kmgradations()}},
\code{\link[=kmlearningpathmatrices]{kmlearningpathmatrices()}},
\code{\link[=kmlearningpaths]{kmlearningpaths()}}
}
\concept{Functions for wellgradedness & learning paths}
\concept{Properties of knowledge structures}
