% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmqspace.R, R/kmqspace.kmfamset.R,
%   R/kmqspace.kmsurmisefunction.R, R/kmqspace.kmsurmiserelation.R
\name{kmqspace}
\alias{kmqspace}
\alias{kmqspace.kmfamset}
\alias{kmqspace.kmsurmisefunction}
\alias{kmqspace.kmsurmiserelation}
\title{Obtain a quasi-ordinal knowledge space}
\usage{
kmqspace(x)

\method{kmqspace}{kmfamset}(x)

\method{kmqspace}{kmsurmisefunction}(x)

\method{kmqspace}{kmsurmiserelation}(x)
}
\arguments{
\item{x}{KST object}
}
\value{
Corresponding \code{kmqspace} object
}
\description{
\code{kmqspace()} computes the  quasi-ordinal space
corresponding to a given KST object.

\code{kmqspace()} computes the smallest quasi-ordinal space
containing a given family of sets.

\code{kmqspace.kmsurmisefunction()} takes a surmise function and
determines the quasi-ordinal knowledge space which is the closure
under intersection of the knowledge space delineated by this surmise
function.

\code{kmqspace.kmsurmiserelation()} computes the quasi-ordinal
knowledge space delineated by a surmise relation
}
\examples{
m <- kmfamset(matrix(c(1,0,0,0,1,0,1,1,1), nrow=3, byrow=TRUE))
kmqspace(m)

m <- kmfamset(matrix(c(1,0,0,0,1,0,1,1,1), nrow=3, byrow=TRUE))
kmqspace(m)

sr <- kmsurmiserelation(xpl$space)
kmqspace(sr)

}
\seealso{
Other Constructors:
\code{\link[=kmfamset]{kmfamset()}},
\code{\link[=kmspace]{kmspace()}},
\code{\link[=kmstructure]{kmstructure()}}
}
\concept{Constructors}
