% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmsetiselement.R
\name{kmsetiselement}
\alias{kmsetiselement}
\title{Test if a state is contained in a family of states}
\usage{
kmsetiselement(s, f)
}
\arguments{
\item{s}{State}

\item{f}{Family of sets}
}
\value{
Boolean is s is contained in f
}
\description{
Test if a state is contained in a family of states
}
\examples{
kmsetiselement(c(1,1,1,0), xpl$space)

}
\seealso{
Other Utilities:
\code{\link[=binary_matrix_product]{binary_matrix_product()}},
\code{\link[=kmdoubleequal]{kmdoubleequal()}},
\code{\link[=kmminimalfamset]{kmminimalfamset()}},
\code{\link[=kmsymmsetdiff]{kmsymmsetdiff()}},
\code{\link{kmtrivial}}
}
\concept{Utilities}
