% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmtrivial.R
\name{kmtrivial}
\alias{kmtrivial}
\alias{kmminimalspace}
\alias{kmmaximalspace}
\title{Create trivial knowledge spaces}
\usage{
kmminimalspace(noi)

kmmaximalspace(noi)
}
\arguments{
\item{noi}{Number of items}
}
\value{
A binary matrix representing the respective knowledge space
}
\description{
These functions create trivial knowledge spaces of a given item number. The minimal
space contains just the empty set and the full item set while the maximal space is
equal to the power set.
}
\details{
Please note that the computation time for creating large power sets can grow quite
large easily.
}
\examples{
kmminimalspace(3)
kmmaximalspace(3)

}
\seealso{
Other Utilities:
\code{\link[=binary_matrix_product]{binary_matrix_product()}},
\code{\link[=kmdoubleequal]{kmdoubleequal()}},
\code{\link[=kmminimalfamset]{kmminimalfamset()}},
\code{\link[=kmsetiselement]{kmsetiselement()}},
\code{\link[=kmsymmsetdiff]{kmsymmsetdiff()}}

Other Functions for working with knowledge structures:
\code{\link[=kmeqreduction]{kmeqreduction()}},
\code{\link[=kmexpand]{kmexpand()}},
\code{\link[=kmintersection]{kmintersection()}},
\code{\link[=kmmesh]{kmmesh()}},
\code{\link[=kmnotions]{kmnotions()}},
\code{\link[=kmsubstructure]{kmsubstructure()}},
\code{\link[=kmunion]{kmunion()}}
}
\concept{Functions for working with knowledge structures}
\concept{Utilities}
