% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmmesh.R
\name{kmmesh}
\alias{kmmesh}
\title{Determine the maximal mesh of two knowledge structures}
\usage{
kmmesh(x, y)
}
\arguments{
\item{x}{First structure}

\item{y}{Second structure}
}
\value{
Maximal mesh
}
\description{
If the two structures are not compatible, NULL is returned.
}
\references{
Falmagne J, Doignon J (1998). “Meshing Knowledge Structures.” In Dowling CE,
Roberts FS, Theuns P (eds.), \emph{Recent Progress in Mathematical Psychology,}
143–153. Lawrence Erlbaum Associates Ltd., Mahwah, NJ.
}
\seealso{
Other Functions for working with knowledge structures:
\code{\link[=kmeqreduction]{kmeqreduction()}},
\code{\link[=kmexpand]{kmexpand()}},
\code{\link[=kmintersection]{kmintersection()}},
\code{\link[=kmnotions]{kmnotions()}},
\code{\link[=kmsubstructure]{kmsubstructure()}},
\code{\link{kmtrivial}},
\code{\link[=kmunion]{kmunion()}}
}
\concept{Functions for working with knowledge structures}
