% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/binarymatrixproduct.R
\name{binary_matrix_product}
\alias{binary_matrix_product}
\title{Compute a binary matrix product}
\usage{
binary_matrix_product(m, n)
}
\arguments{
\item{m}{Binary matrix}

\item{n}{Binary matrix}
}
\value{
Boolean matrix product of m and n
}
\description{
\code{binary_matrix_product} expects two binary matrices and computes their Boolean product.
}
\examples{
binary_matrix_product(xpl$sr, kmsurmiserelation(kmmaximalspace(4)))
binary_matrix_product(xpl$sr, kmsurmiserelation(kmminimalspace(4)))


}
\seealso{
Other Utilities:
\code{\link[=kmdoubleequal]{kmdoubleequal()}},
\code{\link[=kmminimalfamset]{kmminimalfamset()}},
\code{\link[=kmsetiselement]{kmsetiselement()}},
\code{\link[=kmsymmsetdiff]{kmsymmsetdiff()}},
\code{\link{kmtrivial}}
}
\concept{Utilities}
