% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmintersectionclosure.R
\name{kmintersectionclosure}
\alias{kmintersectionclosure}
\title{Close a knowledge space under intersection}
\usage{
kmintersectionclosure(x)
}
\arguments{
\item{x}{Knowledge space}
}
\value{
Quasi--ordinal knowledge space
}
\description{
Close a knowledge space under intersection
}
\examples{
kmintersectionclosure(xpl$space)

}
\seealso{
Other Closure operators:
\code{\link[=kmclosure]{kmclosure()}},
\code{\link[=kmunionclosure]{kmunionclosure()}}
}
\concept{Closure operators}
