% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmexpand.R
\name{kmexpand}
\alias{kmexpand}
\title{Expand an attribution function to a larger set of items and close it to a surmise function}
\usage{
kmexpand(af, ni)
}
\arguments{
\item{af}{Attribution function}

\item{ni}{New (complete) item list}
}
\value{
Expanded surmise function
}
\description{
\code{kmexpand()} expands an attribution function by additional items and
closes it to a surmise function.
}
\examples{
xpl$sf
kmexpand(xpl$sf, c("a", "b", "c", "d", "e", "f"))


}
\seealso{
Other Functions for working with knowledge structures:
\code{\link[=kmeqreduction]{kmeqreduction()}},
\code{\link[=kmintersection]{kmintersection()}},
\code{\link[=kmmesh]{kmmesh()}},
\code{\link[=kmnotions]{kmnotions()}},
\code{\link[=kmsubstructure]{kmsubstructure()}},
\code{\link{kmtrivial}},
\code{\link[=kmunion]{kmunion()}}
}
\concept{Functions for working with knowledge structures}
