% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmheights.R
\name{kmheights}
\alias{kmheights}
\title{Compute the heights of items in a knowledge space specified through its basis}
\usage{
kmheights(b)
}
\arguments{
\item{b}{Basis}
}
\value{
Data.frame with a table of heights.
}
\description{
The height of an item in the knowledge space is defined as the minimal
cardinality of the states containing it minus 1, i.e. the minimal number
of prerequisites.
}
\examples{
kmheights(xpl$basis)

}
\seealso{
Other Properties of knowledge structures:
\code{\link[=kmiswellgraded]{kmiswellgraded()}},
\code{\link[=kmnotions]{kmnotions()}}
}
\concept{Properties of knowledge structures}
