% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmeqreduction.R
\name{kmeqreduction}
\alias{kmeqreduction}
\title{Reduce a family of knowledge states with respect to item equivalence}
\usage{
kmeqreduction(x)
}
\arguments{
\item{x}{Family of sets (\code{kmfamset} object)}
}
\value{
Binary matrix reduced by equivalences
}
\description{
\code{kmeqreduction} takes a family of knowledge states and returns its
reduction to non-equivalent items.
}
\examples{
kmeqreduction(xpl$space)

}
\seealso{
Other Functions for working with knowledge structures:
\code{\link[=kmexpand]{kmexpand()}},
\code{\link[=kmintersection]{kmintersection()}},
\code{\link[=kmmesh]{kmmesh()}},
\code{\link[=kmnotions]{kmnotions()}},
\code{\link[=kmsubstructure]{kmsubstructure()}},
\code{\link{kmtrivial}},
\code{\link[=kmunion]{kmunion()}}
}
\concept{Functions for working with knowledge structures}
