% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmlearningpaths.R
\name{kmlearningpaths}
\alias{kmlearningpaths}
\title{Determine all learning paths in a knowledge structure}
\usage{
kmlearningpaths(
  structure,
  through = NULL,
  from = NULL,
  to = NULL,
  simplified = FALSE
)
}
\arguments{
\item{structure}{Knowledge structure}

\item{through}{Knowledge state through which the paths should go}

\item{from}{Knowledge state where paths should start}

\item{to}{Knowledge state where paths should end}

\item{simplified}{Simplified printing of states within the paths (default FALSE)}
}
\value{
A list of learning paths where each learning path is a
list of states

If \code{through} is specified, only those learning paths are listed
which go through that state (binary vector). If \code{from} and
\code{to} are specified, the respective sub paths are returned.
}
\description{
Determine all learning paths in a knowledge structure
}
\examples{
kmlearningpaths(xpl$space)


}
\seealso{
Other Functions for wellgradedness & learning paths:
\code{\link[=kmgradations]{kmgradations()}},
\code{\link[=kmiswellgraded]{kmiswellgraded()}},
\code{\link[=kmlearningpathmatrices]{kmlearningpathmatrices()}}
}
\concept{Functions for wellgradedness & learning paths}
