% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmlearningpathmatrices.R
\name{kmlearningpathmatrices}
\alias{kmlearningpathmatrices}
\title{Determine all learning paths in a knowledge structure}
\usage{
kmlearningpathmatrices(structure, through = NULL, from = NULL, to = NULL)
}
\arguments{
\item{structure}{Knowledge structure}

\item{through}{Knowledge state through which the paths should go}

\item{from}{Knowledge state where paths should start}

\item{to}{Knowledge state where paths should end}
}
\value{
A list of learning paths where each learning path matrix

If \code{through} is specified, only those learning paths are listed
which go through that state (binary vector). If \code{from} and
\code{to} are specified, the respective sub paths are returned.
}
\description{
Determine all learning paths in a knowledge structure
}
\examples{
kmlearningpathmatrices(xpl$space)


}
\seealso{
Other Functions for wellgradedness & learning paths:
\code{\link[=kmgradations]{kmgradations()}},
\code{\link[=kmiswellgraded]{kmiswellgraded()}},
\code{\link[=kmlearningpaths]{kmlearningpaths()}}
}
\concept{Functions for wellgradedness & learning paths}
