% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmbasis.R, R/kmbasis.kmsurmisefunction.R,
%   R/kmbasis.kmsurmiserelation.R, R/kmbasis.matrix.R
\name{kmbasis}
\alias{kmbasis}
\alias{kmbasis.kmsurmisefunction}
\alias{kmbasis.kmsurmiserelation}
\alias{kmbasis.matrix}
\title{Compute the basis of a knowledge space}
\usage{
kmbasis(x)

\method{kmbasis}{kmsurmisefunction}(x)

\method{kmbasis}{kmsurmiserelation}(x)

\method{kmbasis}{matrix}(x)
}
\arguments{
\item{x}{Binary matrix representing a knowledge space}
}
\value{
Binary matrix representing the basis of the corresponding knowledge space.
}
\description{
\code{kmbasis.kmsurmisefunction} takes a surmise function and returns
the corresponding basis, i.e. effectively the collection of all clauses
in the surmise function.

\code{kmbasis.kmsurmiserelation} takes a surmise relation and returns the
corresponding basis.

\code{kmbasis.matrix} returns a matrix representing the basis of a
knowledge space. If \code{x} is a knowledge structure or an
arbitrary family of sets \code{kmbasis} returns the basis of
the smallest knowledge space containing \code{x}.
}
\examples{
kmbasis(xpl$sf)


kmbasis(xpl$sr)

kmbasis(xpl$space)

}
\seealso{
Other Different representations for knowledge structures:
\code{\link[=kmspace]{kmspace()}},
\code{\link[=kmsurmisefunction]{kmsurmisefunction()}},
\code{\link[=kmsurmiserelation]{kmsurmiserelation()}}
}
\concept{Different representations for knowledge structures}
