% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmunion.R, R/kmunion.famset.R,
%   R/kmunion.kmbasis.R, R/kmunion.kmspace.R, R/kmunion.kmstructure.R,
%   R/kmunion.kmsurmisefunction.R, R/kmunion.kmsurmiserelation.R
\name{kmunion}
\alias{kmunion}
\alias{kmunion.kmfamset}
\alias{kmunion.kmbasis}
\alias{kmunion.kmspace}
\alias{kmunion.kmstructure}
\alias{kmunion.kmsurmisefunction}
\alias{kmunion.kmsurmiserelation}
\title{Compute the "union" of two KST objects}
\usage{
kmunion(x, y)

\method{kmunion}{kmfamset}(x, y)

\method{kmunion}{kmbasis}(x, y)

\method{kmunion}{kmspace}(x, y)

\method{kmunion}{kmstructure}(x, y)

\method{kmunion}{kmsurmisefunction}(x, y)

\method{kmunion}{kmsurmiserelation}(x, y)
}
\arguments{
\item{x}{First object}

\item{y}{Second object}
}
\value{
\emph{Union} of \code{x} and \code{y}
}
\description{
Both objects must be of the same kstMatrix class, the result will be
of the same class, i.e. a respective closure operator will be executed
automatically.
}
\details{
For surmise functions, the algorithm by Dowling & Hockemeyer (1998) is used.

Please note that, for families of sets, there are the functions
\code{kmunionclosure()} and \code{kmintersectionclosure()}.
}
\references{
Dowling CE, Hockemeyer C (1998). “Computing the Intersection
of Knowledge Spaces Using only their Basis.” In Dowling CE, Roberts FS,
Theuns P (eds.), \emph{Recent Progress in Mathematical Psychology,} 133–141.
Lawrence Erlbaum Associates Ltd., Mahwah, NJ.
}
\seealso{
Other Functions for working with knowledge structures:
\code{\link[=kmeqreduction]{kmeqreduction()}},
\code{\link[=kmexpand]{kmexpand()}},
\code{\link[=kmintersection]{kmintersection()}},
\code{\link[=kmmesh]{kmmesh()}},
\code{\link[=kmnotions]{kmnotions()}},
\code{\link[=kmsubstructure]{kmsubstructure()}},
\code{\link{kmtrivial}}
}
\concept{Functions for working with knowledge structures}
