% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmunionclosure.R
\name{kmunionclosure}
\alias{kmunionclosure}
\title{Close a family of sets under union, i.e. determine the smallest knowledge space containing it}
\usage{
kmunionclosure(x)
}
\arguments{
\item{x}{Family of set}
}
\value{
Knowledge space

\code{kmunionclosure} implements the irredundant algorithm developed by Dowling (1993).
}
\description{
Close a family of sets under union, i.e. determine the smallest knowledge space containing it
}
\examples{
kmunionclosure(xpl$basis)


}
\references{
Dowling, C. E. (1993). On the irredundant construction of knowledge spaces.
\emph{Journal of Mathematical Psychology, 37,} 49–62.
}
\seealso{
Other Closure operators:
\code{\link[=kmclosure]{kmclosure()}},
\code{\link[=kmintersectionclosure]{kmintersectionclosure()}}
}
\concept{Closure operators}
