% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Deprecated.R
\name{kmbasisdiagram}
\alias{kmbasisdiagram}
\title{DEPRECATED: \code{kmbasisdiagram()} has been replaced by a \code{plot()} method.}
\usage{
kmbasisdiagram(x, horizontal = TRUE, colors = NULL)
}
\arguments{
\item{x}{Basis}

\item{horizontal}{Boolean whether the diagram should be drawn horizontally or vertically (default TRUE)}

\item{colors}{Color vector (default NULL)}
}
\description{
DEPRECATED: \code{kmbasisdiagram()} has been replaced by a \code{plot()} method.
}
\seealso{
Other Deprecated functions and methods:
\code{\link[=kmSF2basis]{kmSF2basis()}},
\code{\link[=kmSR2basis]{kmSR2basis()}},
\code{\link[=kmSRdiagram]{kmSRdiagram()}},
\code{\link[=kmhasse]{kmhasse()}}
}
\concept{Deprecated functions and methods}
