% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmspace.R, R/kmspace.kmdata.R,
%   R/kmspace.kmfamset.R, R/kmspace.kmsurmisefunction.R,
%   R/kmspace.kmsurmiserelation.R
\name{kmspace}
\alias{kmspace}
\alias{kmspace.kmdata}
\alias{kmspace.kmfamset}
\alias{kmspace.kmsurmisefunction}
\alias{kmspace.kmsurmiserelation}
\title{\code{kmspace} constructor method}
\usage{
kmspace(x)

\method{kmspace}{kmdata}(x)

\method{kmspace}{kmfamset}(x)

\method{kmspace}{kmsurmisefunction}(x)

\method{kmspace}{kmsurmiserelation}(x)
}
\arguments{
\item{x}{KST object}
}
\value{
Corresponding knowledge space
}
\description{
\code{kmspace()} determines the knowledge space corresponding to a KST object

Please note that a knowledge space delineated by a surmise relation is
quasi-ordinal. Therefore, the result is automatically marked as
\code{kmqspace} object.
}
\examples{
kmspace(xpl$basis)
kmspace(xpl$sf)

}
\seealso{
Other Constructors:
\code{\link[=kmfamset]{kmfamset()}},
\code{\link[=kmqspace]{kmqspace()}},
\code{\link[=kmstructure]{kmstructure()}}

Other Different representations for knowledge structures:
\code{\link[=kmbasis]{kmbasis()}},
\code{\link[=kmsurmisefunction]{kmsurmisefunction()}},
\code{\link[=kmsurmiserelation]{kmsurmiserelation()}}
}
\concept{Constructors}
\concept{Different representations for knowledge structures}
