% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmclosure.R,
%   R/kmclosure.kmattributionfunction.R, R/kmclosure.kmattributionrelation.R,
%   R/kmclosure.kmdata.R, R/kmclosure.kmfamset.R
\name{kmclosure}
\alias{kmclosure}
\alias{kmclosure.kmattributionfunction}
\alias{kmclosure.kmattributionrelation}
\alias{kmclosure.kmdata}
\alias{kmclosure.kmfamset}
\title{Determine the closure of KST objects}
\usage{
kmclosure(x, ...)

\method{kmclosure}{kmattributionfunction}(x, ...)

\method{kmclosure}{kmattributionrelation}(x, ...)

\method{kmclosure}{kmdata}(x, ...)

\method{kmclosure}{kmfamset}(x, ..., closure = "union")
}
\arguments{
\item{x}{KST object}

\item{...}{Optional additional parameters}

\item{closure}{Type of closure

For families of sets (\code{kmfamset}), kmclosure is basically a wrapper
for \code{kmunionclosure()} and \code{kmintersectionclosure}.
\code{closure()} may take the values "union" (default) or "intersection".
The former requests a closure under union, the latter a closure under
union \strong{and} intersection.}
}
\value{
Corresponding closed KST object

An attribution relation or
attribution function is closed to the corresponding surmise relation
or surmise function, respectively.

A family of sets (including bases, knowledge structure, and knowledge space)
is closed to a knowledge space or quasi-ordinal knowledge space.
}
\description{
\code{kmclosure()} is an S3 method closing \code{kstMatrix} objects.
}
\seealso{
Other Closure operators:
\code{\link[=kmintersectionclosure]{kmintersectionclosure()}},
\code{\link[=kmunionclosure]{kmunionclosure()}}
}
\concept{Closure operators}
