% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmintersection.R, R/kmintersection.kmqspace.R,
%   R/kmintersection.kmspace.R, R/kmintersection.kmsurmisefunction.R,
%   R/kmintersection.kmsurmiserelation.R
\name{kmintersection}
\alias{kmintersection}
\alias{kmintersection.kmqspace}
\alias{kmintersection.kmspace}
\alias{kmintersection.kmsurmisefunction}
\alias{kmintersection.kmsurmiserelation}
\title{Compute the "intersection" of two KST objects}
\usage{
kmintersection(x, y)

\method{kmintersection}{kmqspace}(x, y)

\method{kmintersection}{kmspace}(x, y)

\method{kmintersection}{kmsurmisefunction}(x, y)

\method{kmintersection}{kmsurmiserelation}(x, y)
}
\arguments{
\item{x}{First KST object}

\item{y}{Second KST object}
}
\value{
\emph{Intersection} of \code{x} and \code{y}
}
\description{
Both objects must be of the same kstMatrix class, the result will be
of the same class, i.e. a respective closure operator will be executed
automatically.

Please note that the intersection of surmise relations is automatically
a surmise relation without any closure needs.
}
\examples{
sf <- kmsurmisefunction(kmbasis(xpl$sr))
kmintersection(xpl$sf, sf)

}
\seealso{
Other Functions for working with knowledge structures:
\code{\link[=kmeqreduction]{kmeqreduction()}},
\code{\link[=kmexpand]{kmexpand()}},
\code{\link[=kmmesh]{kmmesh()}},
\code{\link[=kmnotions]{kmnotions()}},
\code{\link[=kmsubstructure]{kmsubstructure()}},
\code{\link{kmtrivial}},
\code{\link[=kmunion]{kmunion()}}
}
\concept{Functions for working with knowledge structures}
