% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmsurmisefunction.R
\name{kmsurmisefunction}
\alias{kmsurmisefunction}
\title{Compute the surmise function for a knowledge space or basis}
\usage{
kmsurmisefunction(x, itemname = "Item")
}
\arguments{
\item{x}{Binary matrix representing a knowledge space or basis}

\item{itemname}{Name for the first column of the resulting data frame}
}
\value{
Data frame  representing the surmise unction of \code{x}.
}
\description{
\code{kmsurmisefunction} returns a data frame representing the
surmise function for a knowledge space or basis. The rows of the
data frame are ordered by item name.
}
\examples{
kmsurmisefunction(xpl$space)

}
\seealso{
Other Different representations for knowledge structures:
\code{\link[=kmbasis]{kmbasis()}},
\code{\link[=kmspace]{kmspace()}},
\code{\link[=kmsurmiserelation]{kmsurmiserelation()}}
}
\concept{Different representations for knowledge structures}
