% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/kmrefine.R
\name{kmrefine}
\alias{kmrefine}
\title{Refine a famset by dissolving a notion through a basis on the notion}
\usage{
kmrefine(x, b)
}
\arguments{
\item{x}{Family of sets}

\item{b}{Basis for refinement}
}
\value{
Refined family of sets
}
\description{
Refine a famset by dissolving a notion through a basis on the notion
}
\examples{
x <- kmfamset(matrix(c(1,0,0,0,0,1,0,0,1,1,1,1), ncol=4, byrow=TRUE))
colnames(x) <- c("a", "b", "c", "d")
x
b <- kmbasis(kmfamset(matrix(c(1,0,1,1), ncol=2, byrow=TRUE)))
colnames(b) <- c("c", "d")
b
kmrefine(x,b)

}
